@@ -21,6 +21,7 @@ from yowsup.layers.protocol_chatstate.protocolentities   import *
 from yowsup.layers.protocol_privacy.protocolentities     import *
 from yowsup.layers.protocol_media.protocolentities       import *
 from yowsup.layers.protocol_media.mediauploader import MediaUploader
+from yowsup.layers.protocol_profiles.protocolentities    import *
 from yowsup.layers.axolotl.protocolentities.iq_key_get import GetKeysIqProtocolEntity
 from yowsup.layers.axolotl import YowAxolotlLayer
 
@@ -167,16 +168,24 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
 
     ######################################
 
+    ####### contacts/ profiles ####################
+    @clicmd("Get profile picture for contact")
+    def contact_picture(self, jid):
+        if self.assertConnected():
+            entity = PictureIqProtocolEntity(self.aliasToJid(jid))
+            self.toLower(entity)
+
     @clicmd("List all groups you belong to", 5)
     def groups_list(self):
         if self.assertConnected():
             entity = ListGroupsIqProtocolEntity()
             self.toLower(entity)
 
-    #@clicmd("Leave a group you belong to", 4)
+    @clicmd("Leave a group you belong to", 4)
     def group_leave(self, jid):
-        #entity = LeaveGroupIqProtocolEntity([jid])
-        print("LEAVE GROUP %s" % jid)
+        if self.assertConnected():
+            entity = LeaveGroupsIqProtocolEntity([self.aliasToJid(jid)])
+            self.toLower(entity)
 
     @clicmd("Create a new group with the specified subject", 3)
     def groups_create(self, subject):
@@ -185,9 +194,11 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
             self.addToIqs(entity)
             self.toLower(entity)
 
-    #@clicmd("Invite to group")
+    @clicmd("Invite to group")
     def group_invite(self, group_jid, jid):
-        pass
+        if self.assertConnected():
+            entity = AddParticipantsIqProtocolEntity(self.aliasToJid(group_jid), self.aliasToJid(jid))
+            self.toLower(entity)
 
     @clicmd("Get pariticipants in a group")
     def group_participants(self, group_jid):
@@ -238,7 +249,7 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
     @clicmd("Send message to a friend")
     def message_send(self, number, content):
         if self.assertConnected():
-            outgoingMessage = TextMessageProtocolEntity(content, to = self.aliasToJid(number))
+            outgoingMessage = TextMessageProtocolEntity(content.encode("utf-8") if sys.version_info >= (3,0) else content, to = self.aliasToJid(number))
             self.toLower(outgoingMessage)
 
     @clicmd("Broadcast message. numbers should comma separated phone numbers")
@@ -361,7 +372,7 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
             messageOut = self.getMediaMessageBody(message)
         else:
             messageOut = "Unknown message type %s " % message.getType()
-            print(message.toProtocolTreeNode())
+            print(messageOut.toProtocolTreeNode())
 
 
         formattedDate = datetime.datetime.fromtimestamp(message.getTimestamp()).strftime('%d-%m-%Y %H:%M')
@@ -400,6 +411,8 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
     def doSendImage(self, filePath, url, to, ip = None):
         entity = ImageDownloadableMediaMessageProtocolEntity.fromFilePath(filePath, url, ip, to)
         self.toLower(entity)
+    def __str__(self):
+        return "CLI Interface Layer"
 
     ########### callbacks ############
 
