@@ -18,7 +18,12 @@ class SendLayer(YowInterfaceLayer):
         self.lock.acquire()
         for target in self.getProp(self.__class__.PROP_MESSAGES, []):
             phone, message = target
-            messageEntity = TextMessageProtocolEntity(message, to = "%s@s.whatsapp.net" % phone)
+            if '@' in phone:
+                messageEntity = TextMessageProtocolEntity(message, to = phone)
+            elif '-' in phone:
+                messageEntity = TextMessageProtocolEntity(message, to = "%s@g.us" % phone)
+            else:
+                messageEntity = TextMessageProtocolEntity(message, to = "%s@s.whatsapp.net" % phone)
             self.ackQueue.append(messageEntity.getId())
             self.toLower(messageEntity)
         self.lock.release()
