@@ -2,11 +2,11 @@ from .env import YowsupEnv
 import base64
 import hashlib
 class S40YowsupEnv(YowsupEnv):
-    _VERSION = "2.12.60"
+    _VERSION = "2.12.61"
     _OS_NAME= "S40"
-    _OS_VERSION = "14.26"
-    _DEVICE_NAME = "Nokia302"
-    _TOKEN_STRING  = "PdA2DJyKoUrwLw1Bg6EIhzh502dF9noR9uFCllGk1418865329241{phone}"
+    _OS_VERSION = "08.71"
+    _DEVICE_NAME = "NokiaX2-01"
+    _TOKEN_STRING  = "PdA2DJyKoUrwLw1Bg6EIhzh502dF9noR9uFCllGk1419900882708{phone}"
     _AXOLOTL = False
 
     def getVersion(self):
