@@ -5,6 +5,7 @@ from .layer_crypt import YowCryptLayer
 from yowsup.layers.network import YowNetworkLayer
 from .autherror import AuthError
 from .protocolentities import *
+from yowsup.common.tools import StorageTools
 import base64
 class YowAuthenticationProtocolLayer(YowProtocolLayer):
     EVENT_LOGIN      = "org.openwhatsapp.yowsup.event.auth.login"
@@ -27,6 +28,8 @@ class YowAuthenticationProtocolLayer(YowProtocolLayer):
 
     def __getCredentials(self):
         u, pb64 = self.getProp(YowAuthenticationProtocolLayer.PROP_CREDENTIALS)
+        if type(pb64) is str:
+            pb64 = pb64.encode()
         password = base64.b64decode(pb64)
         return (u, bytearray(password))
 
@@ -49,6 +52,7 @@ class YowAuthenticationProtocolLayer(YowProtocolLayer):
         nodeEntity = StreamFeaturesProtocolEntity.fromProtocolTreeNode(node)
 
     def handleSuccess(self, node):
+        if(node.data != None): StorageTools.writeNonce(self.credentials[0],node.data)
         successEvent = YowLayerEvent(self.__class__.EVENT_AUTHED, passive = self.getProp(self.__class__.PROP_PASSIVE))
         self.broadcastEvent(successEvent)
         nodeEntity = SuccessProtocolEntity.fromProtocolTreeNode(node)
@@ -70,9 +74,30 @@ class YowAuthenticationProtocolLayer(YowProtocolLayer):
 
     def _sendAuth(self):
         passive = self.getProp(self.__class__.PROP_PASSIVE, False)
-        self.entityToLower(AuthProtocolEntity(self.credentials[0], passive=passive))
+        nonce = StorageTools.getNonce(self.credentials[0])
+
+        if nonce == None:
+            self.entityToLower(AuthProtocolEntity(self.credentials[0], passive=passive))
+        else:
+            inputKey, outputKey, authBlob = self.generateAuthBlob(nonce)
+            #to prevent enr whole response
+            self.broadcastEvent(YowLayerEvent(YowCryptLayer.EVENT_KEYS_READY, keys = (inputKey, None)))
+            self.entityToLower(AuthProtocolEntity(self.credentials[0], passive=passive, nonce=authBlob))
+            self.broadcastEvent(YowLayerEvent(YowCryptLayer.EVENT_KEYS_READY, keys = (inputKey, outputKey)))
+
 
     def _sendResponse(self,nonce):
+        inputKey, outputKey, authBlob = self.generateAuthBlob(nonce)
+        responseEntity = ResponseProtocolEntity(authBlob)
+
+        #to prevent enr whole response
+        self.broadcastEvent(YowLayerEvent(YowCryptLayer.EVENT_KEYS_READY, keys = (inputKey, None))) 
+        self.entityToLower(responseEntity)
+        self.broadcastEvent(YowLayerEvent(YowCryptLayer.EVENT_KEYS_READY, keys = (inputKey, outputKey)))
+        #YowCryptLayer.setProp("outputKey", outputKey)
+
+
+    def generateAuthBlob(self, nonce):
         keys = KeyStream.generateKeys(self.credentials[1], nonce)
 
         inputKey = KeyStream(keys[2], keys[3])
@@ -99,12 +124,4 @@ class YowAuthenticationProtocolLayer(YowProtocolLayer):
         encoded = outputKey.encodeMessage(nums, 0, 4, len(nums) - 4)
         authBlob = "".join(map(chr, encoded))
 
-        responseEntity = ResponseProtocolEntity(authBlob)
-
-        #to prevent enr whole response
-        self.broadcastEvent(YowLayerEvent(YowCryptLayer.EVENT_KEYS_READY, keys = (inputKey, None))) 
-        self.entityToLower(responseEntity)
-        self.broadcastEvent(YowLayerEvent(YowCryptLayer.EVENT_KEYS_READY, keys = (inputKey, outputKey)))
-        #YowCryptLayer.setProp("outputKey", outputKey)
-
-
+        return (inputKey, outputKey, authBlob)
\ No newline at end of file
